@@ -167,7 +167,7 @@ gkb_prop_list_delete_clicked (GkbPropertyBoxInfo * pbi)
 
   gkb_prop_list_reload (pbi);
 
-  gnome_property_box_changed (GNOME_PROPERTY_BOX (pbi->box));
+  gkb_apply(pbi);
 
   return;
 }
@@ -195,7 +195,7 @@ gkb_util_g_list_swap (GList * item1, GList * item2)
  * @pbi: 
  * @up: 
  * 
- * 
+ * Property box Up or Down button clicked
  **/
 static void
 gkb_prop_list_up_down_clicked (GkbPropertyBoxInfo * pbi, gboolean up)
@@ -220,7 +220,7 @@ gkb_prop_list_up_down_clicked (GkbPropertyBoxInfo * pbi, gboolean up)
 
   gkb_prop_list_reload (pbi);
 
-  gnome_property_box_changed (GNOME_PROPERTY_BOX (pbi->box));
+  gkb_apply(pbi);
 
   return;
 }
