@@ -80,7 +80,7 @@ const gchar multiload_menu_xml [] =
 void
 start_procman_cb (BonoboUIComponent *uic, gpointer data, const gchar *name)
 {
-	gnome_execute_shell(NULL, "procman");
+	gnome_execute_shell(NULL, "gnome-system-monitor");
 	return;
 }
               
@@ -346,4 +346,4 @@ PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MultiLoadApplet_Factory",
 				   "MultiLoad Applet factory",
 				   "0",
 				   multiload_factory,
-				   NULL);
\ No newline at end of file
+				   NULL);
